Stan Math Library: stan/math/prim/mat/prob/ordered_logistic_log.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
ordered_logistic_log.hpp File Reference
`#include <boost/random/uniform_01.hpp>`
`#include <boost/random/variate_generator.hpp>`
`#include <stan/math/prim/scal/fun/inv_logit.hpp>`
`#include <stan/math/prim/scal/fun/log1m.hpp>`
`#include <stan/math/prim/scal/fun/log1m_exp.hpp>`
`#include <stan/math/prim/scal/fun/log1p_exp.hpp>`
`#include <stan/math/prim/scal/err/check_bounded.hpp>`
`#include <stan/math/prim/scal/err/check_finite.hpp>`
`#include <stan/math/prim/scal/err/check_greater.hpp>`
`#include <stan/math/prim/scal/err/check_less.hpp>`
`#include <stan/math/prim/scal/err/check_less_or_equal.hpp>`
`#include <stan/math/prim/scal/err/check_nonnegative.hpp>`
`#include <stan/math/prim/scal/err/check_positive.hpp>`
`#include <stan/math/prim/scal/fun/constants.hpp>`
`#include <stan/math/prim/mat/prob/categorical_rng.hpp>`
`#include <stan/math/prim/scal/meta/include_summand.hpp>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T >
T | stan::math::log_inv_logit_diff (const T &alpha, const T &beta)
template<bool propto, typename T_lambda , typename T_cut >
boost::math::tools::promote_args< T_lambda, T_cut >::type | stan::math::ordered_logistic_log (int y, const T_lambda &lambda, const Eigen::Matrix< T_cut, Eigen::Dynamic, 1 > &c)
| Returns the (natural) log probability of the specified integer outcome given the continuous location and specified cutpoints in an ordered logistic model. More...
template<typename T_lambda , typename T_cut >
boost::math::tools::promote_args< T_lambda, T_cut >::type | stan::math::ordered_logistic_log (int y, const T_lambda &lambda, const Eigen::Matrix< T_cut, Eigen::Dynamic, 1 > &c)

[ Stan Home Page ] © 2011–2016, Stan Development Team.